@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,10 +22,11 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_CUSTOM_WIDGET_FOR_BINDINGS_HPP
 #define TGUI_CUSTOM_WIDGET_FOR_BINDINGS_HPP
 
+#ifndef TGUI_REMOVE_DEPRECATED_CODE
+
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #include <TGUI/Widget.hpp>
@@ -48,7 +49,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
         static constexpr const char StaticWidgetType[] = "CustomWidget"; //!< Type name of the widget
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /// @brief Constructor
@@ -58,14 +58,12 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         CustomWidgetForBindings(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new widget
         /// @return The new widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static CustomWidgetForBindings::Ptr create();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief sets the position of the widget
         ///
@@ -91,7 +89,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setPosition(const Layout2d& position) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the size of the widget
         ///
@@ -111,7 +108,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setSize(const Layout2d& size) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the entire size that the widget is using
         ///
@@ -122,7 +118,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getFullSize() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the distance between the position where the widget is drawn and where the widget is placed
         ///
@@ -132,7 +127,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Vector2f getWidgetOffset() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Shows or hides a widget
         /// @param visible  Is the widget visible?
@@ -142,7 +136,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setVisible(bool visible) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Enables or disables the widget
         /// @param enabled  Is the widget enabled?
@@ -152,7 +145,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setEnabled(bool enabled) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Focus or unfocus the widget
         /// @param focused  Is the widget focused?
@@ -163,21 +155,18 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setFocused(bool focused) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the widget can gain focus
         /// @return Can the widget be focused?
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD bool canGainFocus() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /// This function is called every frame with the time passed since the last frame.
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool updateTime(Duration elapsedTime) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the mouse position (which is relative to the parent widget) lies on top of the widget
         /// @return Is the mouse on top of the widget?
@@ -235,7 +224,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void leftMouseButtonNoLongerDown() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Draw the widget to a render target
         /// @param target Render target to draw to
@@ -243,7 +231,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void draw(BackendRenderTarget& target, RenderStates states) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes a copy of the widget if you don't know its exact type
         ///
@@ -256,7 +243,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr clone() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
@@ -267,19 +253,16 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void rendererChanged(const String& property) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief This function is called when the mouse enters the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void mouseEnteredWidget() override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief This function is called when the mouse leaves the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void mouseLeftWidget() override;
 
-
     public:
 
         std::function<void(Vector2f)>                   implPositionChanged;
@@ -313,6 +296,8 @@ TGUI_MODULE_EXPORT namespace tgui
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 }
 
+#endif // TGUI_REMOVE_DEPRECATED_CODE
+
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 #endif // TGUI_WIDGET_HPP
