@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -28,11 +28,10 @@
 #if !TGUI_EXPERIMENTAL_USE_STD_MODULE
     #include <string>
     #include <cctype> // tolower
+    #include <algorithm> // equal, min
 
     #if TGUI_COMPILED_WITH_CPP_VER >= 17
         #include <string_view>
-    #else
-        #include <algorithm> // min
     #endif
 #endif
 
