@@ -652,9 +652,7 @@ namespace tgui
             if (timePointNextAllowed > timePointNow)
                 continue;
 
-            m_backendRenderTarget->clearScreen();
-            draw();
-            presentScreen(); // Call SDL_GL_SwapWindow or SDL_RenderPresent depending on the backend renderer
+            renderFrame(clearColor);
 
             refreshRequired = false;
             lastRenderTime = std::chrono::steady_clock::now(); // Don't use timePointNow to provide enough rest on low-end hardware
@@ -817,6 +815,15 @@ namespace tgui
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    void BackendGuiSDL::renderFrame(Color)
+    {
+        m_backendRenderTarget->clearScreen();
+        draw();
+        presentScreen(); // Call SDL_GL_SwapWindow or SDL_RenderPresent depending on the backend renderer
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
