@@ -24,9 +24,8 @@
 
 #include <TGUI/Backend/Window/SDL/BackendSDL.hpp>
 
-#if defined TGUI_SYSTEM_WINDOWS && defined _MSC_VER
-    #pragma warning(push)
-    #pragma warning(disable:4121) // alignment of a member was sensitive to packing, in winnt.h
+#ifdef TGUI_SYSTEM_WINDOWS
+    #include <TGUI/extlibs/IncludeWindows.hpp>
 #endif
 
 #include <TGUI/extlibs/IncludeSDL.hpp>
@@ -34,14 +33,6 @@
     #include <SDL_syswm.h>
 #endif
 
-#ifdef TGUI_SYSTEM_WINDOWS
-    #include <TGUI/extlibs/IncludeWindows.hpp>
-#endif
-
-#if defined TGUI_SYSTEM_WINDOWS && defined _MSC_VER
-    #pragma warning(pop)
-#endif
-
 #if defined(TGUI_SYSTEM_LINUX) && defined(TGUI_USE_X11) && (SDL_MAJOR_VERSION < 3) && defined(SDL_VIDEO_DRIVER_X11)
     #include <X11/Xlib.h>
     #include <X11/cursorfont.h>
@@ -259,7 +250,11 @@ namespace tgui
     {
 #ifdef TGUI_SYSTEM_WINDOWS
         // If setting the clipboard fails on Windows then sleep a moment and try again
+#if SDL_MAJOR_VERSION >= 3
+        if (!SDL_SetClipboardText(contents.toStdString().c_str()))
+#else
         if (SDL_SetClipboardText(contents.toStdString().c_str()) < 0)
+#endif
         {
             Sleep(1);
             SDL_SetClipboardText(contents.toStdString().c_str());
@@ -280,8 +275,13 @@ namespace tgui
 #ifdef TGUI_SYSTEM_ANDROID
     std::unique_ptr<std::uint8_t[]> BackendSDL::readFileFromAndroidAssets(const String& filename, std::size_t& fileSize) const
     {
+#if SDL_MAJOR_VERSION >= 3
+        JNIEnv* env = static_cast<JNIEnv*>(SDL_GetAndroidJNIEnv());
+        jobject activity = static_cast<jobject>(SDL_GetAndroidActivity());
+#else
         JNIEnv* env = static_cast<JNIEnv*>(SDL_AndroidGetJNIEnv());
         jobject activity = static_cast<jobject>(SDL_AndroidGetActivity());
+#endif
         jclass clazz = env->GetObjectClass(activity);
 
         jmethodID methodID = env->GetMethodID(clazz, "getAssets", "()Landroid/content/res/AssetManager;");
