@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -123,6 +123,14 @@ namespace tgui
                                                        {"ArrowColorHover", Color::Black},
                                                        {"ArrowBackgroundColor", Color{245, 245, 245}},
                                                        {"ArrowBackgroundColorHover", Color::White}})},
+                    {"ContextMenu", RendererData::create({{"TextColor", Color{60, 60, 60}},
+                                                          {"SelectedTextColor", Color::White},
+                                                          {"BackgroundColor", Color::White},
+                                                          {"SelectedBackgroundColor", Color{0, 110, 255}},
+                                                          {"TextColorDisabled", Color{125, 125, 125}},
+                                                          {"SeparatorColor", Color::Black},
+                                                          {"SeparatorThickness", 1.f},
+                                                          {"SeparatorVerticalPadding", 1.f}})},
                     {"EditBox", RendererData::create({{"Borders", Borders{1}},
                                                       {"Padding", Padding{0}},
                                                       {"CaretWidth", 1.f},
@@ -396,6 +404,14 @@ namespace tgui
             {"BorderColor", ""},
             {"Borders", ""},
         }},
+        {"ContextMenu", {
+            {"BackgroundColor", ""},
+            {"SelectedBackgroundColor", ""},
+            {"TextColor", ""},
+            {"TextColorDisabled", ""},
+            {"SelectedTextColor", ""},
+            {"SeparatorColor", "BorderColor"},
+        }},
         {"EditBox", {
             {"TextColor", ""},
             {"TextColorDisabled", ""},
