@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -39,11 +39,14 @@ namespace tgui
         {"ClickableWidget", std::make_shared<ClickableWidget>},
         {"ColorPicker", std::make_shared<ColorPicker>},
         {"ComboBox", std::make_shared<ComboBox>},
+        {"ContextMenu", std::make_shared<ContextMenu>},
         {"EditBox", std::make_shared<EditBox>},
         {"EditBoxSlider", std::make_shared<EditBoxSlider>},
         {"FileDialog", std::make_shared<FileDialog>},
         {"Grid", std::make_shared<Grid>},
         {"Group", std::make_shared<Group>},
+        {"GrowHorizontalLayout", std::make_shared<GrowHorizontalLayout>},
+        {"GrowVerticalLayout", std::make_shared<GrowVerticalLayout>},
         {"HorizontalLayout", std::make_shared<HorizontalLayout>},
         {"HorizontalWrap", std::make_shared<HorizontalWrap>},
         {"Knob", std::make_shared<Knob>},
