@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2025 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -47,10 +47,10 @@ namespace tgui
         {
             m_renderer = aurora::makeCopied<TabsRenderer>();
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
-        }
 
-        setTextSize(getGlobalTextSize());
-        setTabHeight(std::round(Text::getLineHeight(m_fontCached, m_textSizeCached) * 1.25f) + m_bordersCached.getTop() + m_bordersCached.getBottom());
+            setTextSize(getGlobalTextSize());
+            setTabHeight(std::round(Text::getLineHeight(m_fontCached, m_textSizeCached) * 1.25f) + m_bordersCached.getTop() + m_bordersCached.getBottom());
+        }
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -456,6 +456,16 @@ namespace tgui
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
+    void Tabs::rightMousePressed(Vector2f pos)
+    {
+        leftMousePressed(pos); // Select the tab on which you clicked
+
+        if (m_selectedTab >= 0)
+            onTabRightClick.emit(this, m_tabs[static_cast<std::size_t>(m_selectedTab)].text.getString());
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
     void Tabs::mouseMoved(Vector2f pos)
     {
         Widget::mouseMoved(pos);
@@ -555,6 +565,8 @@ namespace tgui
     {
         if (signalName == onTabSelect.getName())
             return onTabSelect;
+        else if (signalName == onTabRightClick.getName())
+            return onTabRightClick;
         else
             return Widget::getSignal(std::move(signalName));
     }
